# This Python file uses the following encoding: utf-8

__author__="A. Fritz - c.a.t.forge.eu"
__date__ ="$09.09.2009 20:35:14$"
__doc__="Zur Zeit noch keine Dokumentation."

from django import forms
from django.utils.translation import ugettext_lazy as _
#from sitecode.captcha.fields import CaptchaField

class ContactForm(forms.Form):
    """
    Einfaches Mailformular ohne Betreff.
    """
    email = forms.EmailField(required=True)
    subject = forms.Field(required=True)
    message = forms.CharField(widget=forms.Textarea)
#    captcha = CaptchaField()

    def clean_message(self):
        """Prüft auf mindest Wort anzahl"""
        message = self.cleaned_data['message']
        num_words = len(message.split())
        if num_words < 4:
            raise forms.ValidationError(_("Not enough words!"))
        return message



#!/usr/bin/python
# -*- coding:utf-8 -*-
# This Python file uses the following encoding: utf-8

from django.http import HttpResponseRedirect
from django.shortcuts import render_to_response
from django.template import RequestContext  # für extra context
from easy_contact.forms import ContactForm
from django.views.decorators.cache import cache_control
import settings

# We will use smtplib and email instead of django.core.mail. That because we
# can easely get the mail host from database instead of the settings file and
# that without modify djangos core mail.
# There is a bug in smtp lib, so if you run it on a development server it may
# not work as you expect. For more Information see:
# http://stackoverflow.com/questions/383738/104-connection-reset-by-peer-socket-error-or-when-does-closing-a-socket-resul
import smtplib
from smtplib import SMTPException
from email.mime.text import MIMEText


@cache_control(private=True)
def contact(request):
    """
    View für simples Kontaktformular.
    1. It should be possible to us the contact form by give only the reciver adress
    in the django-contac-formt-setup so the server in settings.py will be used
    for sending.
    2. If a full server setup is given in django-contac-formt-setup than it will
    be used
    3. if Complete server setup is not installed then settings.py is used for
    complete mail host setup.

    Anyway, for best results use a smtp server who allowed to send mails with any
    sender adress.
    """
    def get_mail_data():
        """
        If django-contac-formt-setup is installed than get data set from the app if not
        pull it from settings.py
        Also if there are missig data in spite of no server was specified in
        the app than it will be filled up by our setup.py
        """
        # our error message if not enought data available.
        error_message = 'Pleas configure your settings file withthe necessary mailserver settings.'
        d = {}  # dataset

        # Sending with the senders from email we can only try if a complete server setup.
        # is given. Only a mail adress is not enough. In this case we use the
        # from the settings.py.
        send_with_formulars_email_from = False  # so later we will care about this variabls

        # if installed get data from the easy_contact_setup app
        if 'easy_contact_setup' in settings.INSTALLED_APPS:
            from easy_contact_setup.models import Setup
            try:
                m = Setup.objects.filter(active=True)[0]  # choose the first active object
            except IndexError:
                # if no object is activ than give a hint to set on up
                raise IndexError('Create an instance in the easy_contact_setup app a and activate it!')
            d['MAIL_DEFAULT_TO'] = m.mail_to
            d['MAIL_HOST_PASS'] = m.mail_host_pass
            d['MAIL_HOST_USER'] = m.mail_host_user
            d['MAIL_HOST'] = m.mail_host

            # skip settings.py only if all parameters avallible
            if m.mail_host and m.mail_host_pass and m.mail_host_user:
                send_with_formulars_email_from = True
                return d, send_with_formulars_email_from
            else:
                # this will used as sender address if send_with_formulars_email_from
                # is False
                d['MAIL_FROM'] = settings.DEFAULT_FROM_EMAIL

        # else if easy_contact_setup isn't installed then get data from setup.py
        else:
            send_with_formulars_email_from = True
            try:
                d['MAIL_DEFAULT_TO'] = settings.DEFAULT_FROM_EMAIL
            except AttributeError:
                raise AttributeError(error_message)

        # now get ste smtp setup data if not got before
        try:
            d['MAIL_HOST_PASS'] = settings.EMAIL_HOST_PASSWORD
            d['MAIL_HOST_USER'] = settings.EMAIL_HOST_USER
            d['MAIL_HOST'] = settings.EMAIL_HOST
            return d, send_with_formulars_email_from
        except AttributeError:
            # our error message if not enought data available.
            raise AttributeError(error_message)

    # Handle Post data and send the email
    if request.method == 'POST':
        form = ContactForm(request.POST)
        if form.is_valid():
            # first fetch data from database/settings.py and form
            sd, swmd = get_mail_data()
            cd = form.cleaned_data

            # and then create the data set from cleaned post data
            subject = u'Message from %s on website %s' % (cd['email'], request.META['HTTP_HOST'])
            message = u'Subj: %s\n\n%s' % (cd['subject'], cd['message'])
            mail_from = cd['email']  # Absender in Mailformular

            # recipient list may be extendet in future versions
            mail_recipient_list = [sd['MAIL_DEFAULT_TO'], ]

            def get_mime_text_instance(subj=subject, mail_from=mail_from, mail_to=sd['MAIL_DEFAULT_TO']):
                """Create and configure an mime text instance"""
                inst = MIMEText(message.encode('utf-8'), 'plain', 'UTF-8')
                inst['Subject'] = subj
                inst['From'] = mail_from
                inst['To'] = mail_to
                return inst

            # Smtp login
            s = smtplib.SMTP(sd['MAIL_HOST'])
            try:
                s.login(sd['MAIL_HOST_USER'], sd['MAIL_HOST_PASS'])
            except SMTPException:
                s.starttls()
                s.ehlo()
                s.login(sd['MAIL_HOST_USER'], sd['MAIL_HOST_PASS'])

            # Sending the Mail
            if swmd:
                try:
                    # Send mail with the sender adress of the mail form user.
                    msg = get_mime_text_instance()
                    s.sendmail(msg['From'], mail_recipient_list, msg.as_string())
                except smtplib.SMTPSenderRefused:
                    # ups that worked not very well, now we try a different
                    # sender adress.
                    # Now We send with the own default email adress as sender
                    # adress - email services often do not allow to send an
                    # email with a foreign email address.

                    # we create a new MIMEText instance and configure it again (the
                    # old works not anymore)
                    msg = get_mime_text_instance(mail_from=sd['MAIL_DEFAULT_TO'])

                    # and now sending the mail again
                    s.sendmail(msg['From'], mail_recipient_list, msg.as_string())
            else:
                # Here we use all server data from the settings.py except the
                # recivers adress (it comes from the app)
                msg = get_mime_text_instance(mail_from=sd['MAIL_FROM'])
                s.sendmail(msg['From'], mail_recipient_list, msg.as_string())

            s.quit()
            return HttpResponseRedirect('/%s/feedback/success/' % request.LANGUAGE_CODE)
    else:
        form = ContactForm(
            # here we can initialize the form with a message
            initial={'message': ''}
        )

    current_dict = {'form': form, }
    return render_to_response('easy_contact/contact.html', current_dict, context_instance=RequestContext(request))


def thanks(request):
    return render_to_response('easy_contact/success.html', context_instance=RequestContext(request))



#!/usr/bin/python
# -*- coding:utf-8 -*-
# This Python file uses the following encoding: utf-8

from django.http import HttpResponseRedirect
from django.shortcuts import render_to_response
from django.template import RequestContext  # für extra context
from easy_contact.forms import ContactForm
from django.views.decorators.cache import cache_control
import settings

# We use smtplib and email instead of django.core.mail. That because we can
# easely get the mail host from database instead of the settings file and that
# without modify the djangos core mail.
# There is a bug in smtp lib, so if you run it on a development server it may
# not work as you expect. For more Information see:
# http://stackoverflow.com/questions/383738/104-connection-reset-by-peer-socket-error-or-when-does-closing-a-socket-resul
import smtplib
from email.mime.text import MIMEText

@cache_control(private=True)
def contact(request):
    """
    View für simples Kontaktformular.
    """
    def get_mail_data():
        """
        If django-contac-formt-setup is installed than get data set from the app if not
        pull it from settings.py
        """
        d = {}  # dataset
        # if installed get data from the easy_contact_setup app
        if 'easy_contact_setup' in settings.INSTALLED_APPS:
            from easy_contact_setup.models import Setup
            try:
                m = Setup.objects.filter(active=True)[0]  # choose the first active object
            except IndexError:
                # if no object is activ than give a hint to set on up
                raise IndexError('Create an instance in the easy_contact_setup app a and activate it!')
            d['MAIL_DEFAULT_TO'] = m.mail_to
            d['MAIL_HOST_PASS'] = m.mail_host_pass
            d['MAIL_HOST_USER'] = m.mail_host_user
            d['MAIL_HOST'] = m.mail_host
            return d

        # else if easy_contact_setup isn't installed then get data from setup.py
        else:
            try:
                d['MAIL_DEFAULT_TO'] = settings.DEFAULT_FROM_EMAIL
                d['MAIL_HOST_PASS'] = settings.EMAIL_HOST_PASSWORD
                d['MAIL_HOST_USER'] = settings.EMAIL_HOST_USER
                d['MAIL_HOST'] = settings.EMAIL_HOST
                return d
            except AttributeError:
                # our error message if not enought data available.
                raise AttributeError('Pleas configure your settings file withthe necessary mailserver settings.')

    # Handle Post data and send the email
    if request.method == 'POST':
        form = ContactForm(request.POST)
        if form.is_valid():
            # first fetch data from database/settings.py and form
            setup_data = get_mail_data()
            cd = form.cleaned_data

            # and then create the data set from cleaned post data
            subject = u'Message from %s on website %s' % (cd['email'], request.META['HTTP_HOST'])
            message = u'Subj: %s\n\n%s' % (cd['subject'], cd['message'])
            mail_from = cd['email']  # Absender in Mailformular

            # create the data set from database/settings.py
            mail_default_to = setup_data['MAIL_DEFAULT_TO']
            mail_recipient_list = [mail_default_to, ]
            mail_host = setup_data['MAIL_HOST']
            mail_host_user = setup_data['MAIL_HOST_USER']
            mail_host_pass = setup_data['MAIL_HOST_PASS']

            # So now we create and configure an mime text instance
            msg = MIMEText(message.encode('utf-8'), 'plain', 'UTF-8')
            msg['Subject'] = subject
            msg['From'] = mail_from
            msg['To'] = mail_default_to

            # Smtp login
            s = smtplib.SMTP(mail_host)
            s.login(mail_host_user, mail_host_pass)

            # Sending the Mail
            try:
                # Send mail with the sender adress of the mail form user.
                s.sendmail(msg['From'], mail_recipient_list, msg.as_string())
                s.quit()
            except smtplib.SMTPSenderRefused:
                # ups that worked not very well, we now try a different
                # sender adress.
                # We send with the own default email adress as sender adress - email
                # services often do not allow to send an email with a foreign
                # email address.

                # we create a new MIMEText instance and configure it again (the
                # old works not anymore)
                msg = MIMEText(message.encode('utf-8'), 'plain', 'UTF-8')
                msg['Subject'] = subject
                msg['From'] = mail_default_to  # change the sender
                msg['To'] = mail_default_to

                # and now sending the mail again
                s.sendmail(msg['From'], mail_recipient_list, msg.as_string())
                s.quit()

            return HttpResponseRedirect('/%s/feedback/success/' % request.LANGUAGE_CODE)
    else:
        form = ContactForm(
            # here we can initialize the form with a message
            initial={'message': ''}
        )

    current_dict = {'form': form, }
    return render_to_response('easy_contact/contact.html', current_dict, context_instance=RequestContext(request))


def thanks(request):
    return render_to_response('easy_contact/success.html', context_instance=RequestContext(request))



#!/usr/bin/python
# -*- coding:utf-8 -*-
# This Python file uses the following encoding: utf-8

VERSION = (0, 3, 8)
APPLICATION_NAME = "django-easy-contact"
VERSION_str = str(VERSION).strip('()').replace(',', '.').replace(' ', '')
VERSION_INFO = """
"Version: %s

Application description: "A small contact form application".
- Works together with django-contact-form-setup app
- Translated in to german



0.3.3 src folder removed so readme is on the toplevel
0.3.2 Flexible sending methodes
0.3.1 Use smtplib directly instead of django.mail

TODO:
    - write unittests
""" % (VERSION_str,)



import version

__version__ = VERSION = version.VERSION
__doc__ = 'For full documentation review the README file in your package or go to: http://pypi.python.org/pypi/django-dynamic-link/'
__docformat__ = 'txt'


#!/usr/bin/python
# -*- coding:utf-8 -*-
# This Python file uses the following encoding: utf-8

from django.core.mail import send_mail
from django.http import HttpResponseRedirect
from django.shortcuts import render_to_response
from django.template import RequestContext  # für extra context
from easy_contact.forms import ContactForm
from django.views.decorators.cache import cache_control
import settings

@cache_control(private=True)
def contact(request):
    """
    View für simples Kontaktformular.
    """
    def get_mail():
        """
        Ist App django-contact-form-setup installiert werden die darüber zur verfügung gestellten
        Paramerter verwendet. Sind keine Settings vorzufinden oder ist App nicht
        installiert werden Ersatzparamerter aus User verwendet:
        Generiere Empfänger Email, der erste gefunden Nutzer in der
        Gruppe: "mail_support" wird genommen
        """
        try:
            settings.EMAIL_HOST
        except AttributeError:
            raise AttributeError('Please setup the settings.EMAIL_HOST!')

        if 'easy_contact_setup' in settings.INSTALLED_APPS:
            from easy_contact_setup.models import Setting
            m = Setting.objects.filter(active=True)
            if m:
                d = {}
                d.update({'DEFAULT_FROM_EMAIL' : m[0].to_email})
                d.update({'EMAIL_HOST_PASSWORD' : m[0].email_host_password})
                d.update({'EMAIL_HOST_USER' : m[0].email_host_user})
                return d
        else:
            try:
                d = {}
                d.update({'DEFAULT_FROM_EMAIL' : settings.DEFAULT_FROM_EMAIL})
                d.update({'EMAIL_HOST_PASSWORD' : settings.EMAIL_HOST_PASSWORD})
                d.update({'EMAIL_HOST_USER' : settings.EMAIL_HOST_USER})
                return d
            except AttributeError:
                raise AttributeError('''Pleas configure your settings file with
                                        the necessary mailserver settings.''')
        # Configuration Error
        raise IOError(""""Create in the easy_contact_setup app a setting instance and activate it!""")

    if request.method == 'POST':
        form = ContactForm(request.POST)
        if form.is_valid():
            cd = form.cleaned_data
            try:
                # Sende mail mit Absendeadresse des Mailformular Benutzers.
                send_mail(
                    subject='Message from %s on website %s' % (cd['email'], request.META['HTTP_HOST']),
                    message='Subj: ' + cd['subject'] + '\n\n' + cd['message'],
                    from_email=cd['email'],  # Absender in Mailformular
                    recipient_list=[
                                    get_mail()['DEFAULT_FROM_EMAIL'],
                                    ],
                    auth_user=get_mail()['EMAIL_HOST_USER'],
                    auth_password=get_mail()['EMAIL_HOST_PASSWORD'],
                    )
            # Sende mail mit eigener Absendeadresse (Maildienste erlauben
            # oft keine fremde Absendeadressen)
            except:
                send_mail(
                    subject='Message from %s on website %s' % (cd['email'], request.META['HTTP_HOST']),
                    message='Subj: ' + cd['subject'] + '\n\n' + cd['message'],
                    from_email=get_mail()['DEFAULT_FROM_EMAIL'],  # Eigene Mailadresse
                    recipient_list=[
                                    get_mail()['DEFAULT_FROM_EMAIL'],
                                    ],
                    auth_user=get_mail()['EMAIL_HOST_USER'],
                    auth_password=get_mail()['EMAIL_HOST_PASSWORD'],
                    )
            return HttpResponseRedirect('/%s/feedback/success/' % request.LANGUAGE_CODE)
    else:
        form = ContactForm(
            initial={'message': ''}
        )

    current_dict = {'form': form, }
    return render_to_response('easy_contact/contact.html', current_dict, context_instance=RequestContext(request))


def thanks(request):
    return render_to_response('easy_contact/success.html', context_instance=RequestContext(request))



#!/usr/bin/python
# -*- coding:utf-8 -*-
# This Python file uses the following encoding: utf-8

from setuptools import setup, find_packages
import sys
from easy_contact import version
import os

# Read the version from a project file
VERSION = version.VERSION_str

# Get description from README file
long_description = open(
                os.path.join(os.path.dirname(__file__), 'README.rst')).read()

# Build a list with requirements of the app
REQUIRES = []
try:
    import django
except ImportError:
    # Because of the strange update behavior of "pip --upgrade package_name"
    # set requierment only if django not avallible.
    REQUIRES.append('django')

if sys.version_info < (2, 4):
    REQUIRES.append('python >= 2.4')


setup(name='django-easy-contact',
      version=VERSION,
      description='A simple contact form application.',
      long_description=long_description,
      author='Andreas Fritz, digital.elements.li',
      author_email='easy-contact@bitzeit.eu',
      url='https://bitbucket.org/catapela/django-easy-contact',
      download_url='https://pypi.python.org/pypi/django-easy-contact',
      license='BSD',
      packages=find_packages(),
      include_package_data=True,
      keywords="django mail configuration setup mailform",
      classifiers=[
              'Development Status :: 4 - Beta',
              'Framework :: Django',
              'License :: OSI Approved :: BSD License',
              'Operating System :: OS Independent',
              'Programming Language :: Python',
              'Environment :: Console',
              'Natural Language :: English',
              'Natural Language :: German',
              'Intended Audience :: Developers',
              'Intended Audience :: Information Technology',
              'Topic :: Internet',
              'Topic :: Utilities',
              ],
      install_requires=REQUIRES,
      zip_safe=False,
      )



#!/usr/bin/python
# -*- coding:utf-8 -*-
# This Python file uses the following encoding: utf-8

from django.conf.urls.defaults import *

urlpatterns = patterns('easy_contact',
                        (r'^success/$', 'views.thanks'),
                        (r'^contact/$', 'views.contact'),
                        )
